@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: downloader-view.c 7964 2008-02-17 23:23:36Z xan $
+ *  $Id$
  */
 
 #include "config.h" 
@@ -32,24 +32,12 @@
 #include "eel-gconf-extensions.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtkversion.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrendererprogress.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeviewcolumn.h>
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkmenushell.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkstatusicon.h>
+#include <gtk/gtk.h>
 #include <libgnomeui/gnome-icon-lookup.h>
 
+#ifdef HAVE_LIBCANBERRA_GTK
+#include <canberra-gtk.h>
+#endif
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
@@ -153,11 +141,6 @@ downloader_view_class_init (DownloaderViewClass *klass)
 	object_class->finalize = downloader_view_finalize;
 
 	g_type_class_add_private (object_class, sizeof(DownloaderViewPrivate));
-
-#ifdef HAVE_LIBNOTIFY
-	notify_init (PACKAGE);
-#endif
-
 }
 
 static void
@@ -179,9 +162,9 @@ static gboolean
 status_icon_popup_menu_cb (GtkStatusIcon *icon,
 			   guint button,
 			   guint time,
-                           DownloaderView *dv)
+			   DownloaderView *dv)
 {
-        GtkWidget *menu, *item;
+	GtkWidget *menu, *item;
 
 	menu = gtk_menu_new ();
 
@@ -301,13 +284,6 @@ downloader_view_finalize (GObject *object)
 
 	G_OBJECT_CLASS (downloader_view_parent_class)->finalize (object);
 
-#ifdef HAVE_LIBNOTIFY	
-	if (notify_is_initted ())
-	{
-		notify_uninit ();
-	}
-#endif
-
 	if (idle_unref)
 	{
 		ephy_object_idle_unref (embed_shell);
@@ -455,6 +431,13 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 		
 		g_free (downloaded);
 #endif
+#ifdef HAVE_LIBCANBERRA_GTK
+	ca_context_play (ca_gtk_context_get (), 0,
+			CA_PROP_APPLICATION_NAME, _("GNOME Web Browser"),
+			CA_PROP_EVENT_ID, "complete-download",
+			CA_PROP_EVENT_DESCRIPTION, _("Download completed"),
+			NULL);
+#endif
 
 		return;
 	case EPHY_DOWNLOAD_PAUSED:
@@ -550,6 +533,7 @@ queue_show_notification (DownloaderView *dv)
 	if (gtk_status_icon_is_embedded (dv->priv->status_icon))
 	{
 		notify_notification_show (dv->priv->notification, NULL);
+		dv->priv->notification_timeout = 0;
 		return FALSE;
 	}
 
@@ -562,7 +546,11 @@ show_notification_window (DownloaderView *dv)
 	if (gtk_status_icon_is_embedded (dv->priv->status_icon))
 		notify_notification_show (dv->priv->notification, NULL);
 	else
+	{
+		if (dv->priv->notification_timeout != 0)
+			g_source_remove (dv->priv->notification_timeout);
 		dv->priv->notification_timeout = g_timeout_add_seconds (1, (GSourceFunc) queue_show_notification, dv);
+	}
 }
 #endif
 
