@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed-persist.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_EMBED_PERSIST_H
@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <glib.h>
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
