@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Christian Persch
  *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-chooser.h,v 1.5 2004/05/08 20:11:17 chpe Exp $
+ *  $Id$
  */
 
 #ifndef EPHY_FILE_CHOOSER_H
@@ -23,9 +23,7 @@
 
 #include <glib-object.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkfilefilter.h>
-#include <gtk/gtkfilechooserdialog.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -36,7 +34,9 @@ G_BEGIN_DECLS
 #define EPHY_IS_FILE_CHOOSER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_FILE_CHOOSER))
 #define EPHY_FILE_CHOOSER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_FILE_CHOOSER, EphyFileChooserClass))
 
-typedef struct EphyFileChooserPrivate EphyFileChooserPrivate;
+typedef struct _EphyFileChooser		EphyFileChooser;
+typedef struct _EphyFileChooserPrivate	EphyFileChooserPrivate;
+typedef struct _EphyFileChooserClass	EphyFileChooserClass;
 
 typedef enum
 {
@@ -48,18 +48,18 @@ typedef enum
 	EPHY_FILE_FILTER_LAST = EPHY_FILE_FILTER_NONE
 } EphyFileFilterDefault;
 
-typedef struct
+struct _EphyFileChooser
 {
 	GtkFileChooserDialog parent;
 
 	/*< private >*/
 	EphyFileChooserPrivate *priv;
-} EphyFileChooser;
+};
 
-typedef struct
+struct _EphyFileChooserClass
 {
 	GtkFileChooserDialogClass parent_class;
-} EphyFileChooserClass;
+};
 
 GType		 ephy_file_chooser_get_type		(void);
 
