@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmark-action-group.c,v 1.6 2006/09/13 11:34:24 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -30,8 +30,7 @@
 #include "ephy-node-common.h"
 #include "ephy-debug.h"
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 static void
@@ -103,17 +102,15 @@ node_added_cb (EphyNode *parent,
 
 	action = ephy_bookmark_action_new (child, name);
 
+	g_signal_connect_swapped (action, "open-link",
+				  G_CALLBACK (ephy_link_open), action_group);
+
 	g_snprintf (accel, sizeof (accel), "<Actions>/%s/%s",
 		    gtk_action_group_get_name (action_group),
 		    name);
 	gtk_action_set_accel_path (action, accel);
 	gtk_action_group_add_action (action_group, action);
 	g_object_unref (action);
-
-	ephy_bookmark_action_updated ((EphyBookmarkAction *) action);
-
-	g_signal_connect_swapped (action, "open-link",
-				  G_CALLBACK (ephy_link_open), action_group);
 }
 
 static void
