@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmark-action.c 7730 2007-11-25 13:47:48Z cosimoc $
+ *  $Id$
  */
 
 #include "config.h"
@@ -32,21 +32,10 @@
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 #include "ephy-dnd.h"
+#include "ephy-string.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtkmain.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
+#include <gtk/gtk.h>
 
 #include <string.h>
 
@@ -78,7 +67,72 @@ enum
 	PROP_ICON
 };
 
-static GObjectClass *parent_class;
+typedef struct
+{
+	GObject *weak_ptr;
+	GtkWidget *entry;
+	EphyLinkFlags flags;
+} ClipboardCtx;
+
+G_DEFINE_TYPE (EphyBookmarkAction, ephy_bookmark_action, EPHY_TYPE_LINK_ACTION)
+
+static void
+clipboard_text_received_cb (GtkClipboard *clipboard,
+			    const char *text,
+			    ClipboardCtx *ctx)
+{
+	if (ctx->weak_ptr != NULL && text != NULL)
+	{
+		/* This is to avoid middle-clicking on a non-empty smart bookmark
+		 * triggering another search.
+		 */
+		if (strcmp (text, gtk_entry_get_text (GTK_ENTRY (ctx->entry))) != 0)
+		{
+			gtk_entry_set_text (GTK_ENTRY (ctx->entry), text);
+		}
+	}
+
+	if (ctx->weak_ptr != NULL)
+	{
+		GObject **object = &(ctx->weak_ptr);
+		g_object_remove_weak_pointer (G_OBJECT (ctx->weak_ptr), 
+					      (gpointer *)object);
+	}
+
+	g_slice_free (ClipboardCtx, ctx);
+}
+
+static gboolean
+entry_button_press_event_cb (GtkWidget *entry,
+			     GdkEventButton *event,
+			     GtkAction *action)
+{
+	if (event->button == 2) /* middle click */
+	{
+		ClipboardCtx *ctx;
+		GObject **object;
+
+		ctx = g_slice_new (ClipboardCtx);
+		ctx->flags = EPHY_LINK_NEW_TAB | EPHY_LINK_JUMP_TO;
+		ctx->entry = entry;
+
+		/* We need to make sure we know if the action is destroyed between
+		 * requesting the clipboard contents, and receiving them.
+	 	 */
+
+		ctx->weak_ptr = G_OBJECT (action);
+		object = &(ctx->weak_ptr);
+		g_object_add_weak_pointer (ctx->weak_ptr, (gpointer *)object);
+
+		gtk_clipboard_request_text
+			(gtk_widget_get_clipboard (entry, GDK_SELECTION_PRIMARY),
+			 (GtkClipboardTextReceivedFunc) clipboard_text_received_cb,
+			 ctx);
+		return TRUE;
+	}
+
+	return FALSE;
+}
 
 static GtkWidget *
 create_tool_item (GtkAction *action)
@@ -87,7 +141,7 @@ create_tool_item (GtkAction *action)
 
 	LOG ("Creating tool item for action %p", action);
 
-	item = GTK_ACTION_CLASS (parent_class)->create_tool_item (action);
+	item = GTK_ACTION_CLASS (ephy_bookmark_action_parent_class)->create_tool_item (action);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
@@ -105,6 +159,8 @@ create_tool_item (GtkAction *action)
 	gtk_entry_set_width_chars (GTK_ENTRY (entry), ENTRY_WIDTH_CHARS);
 	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
 	g_object_set_data (G_OBJECT (item), "entry", entry);
+	g_signal_connect (entry, "button-press-event",
+			  G_CALLBACK (entry_button_press_event_cb), action);
 
 	hbox = gtk_hbox_new (FALSE, 3);
 	gtk_widget_show (hbox);
@@ -298,16 +354,17 @@ ephy_bookmark_action_activate (EphyBookmarkAction *action,
 	/* The entered search term is empty, and we have a smart bookmark */
 	if ((text == NULL || text[0] == '\0') && strstr (location, "%s") != NULL)
 	{
-		GnomeVFSURI *uri = gnome_vfs_uri_new (location);
-		if (uri != NULL)
-		{
-			address = g_strconcat (
-					gnome_vfs_uri_get_scheme (uri),
-					"://",
-					gnome_vfs_uri_get_host_name (uri),
-					NULL);
-			gnome_vfs_uri_unref (uri);
-		}
+		char *scheme;
+		char *host_name;
+
+		scheme = g_uri_parse_scheme (location);
+		host_name = ephy_string_get_host_name (location);
+		address = g_strconcat (scheme,
+				       "://",
+				       host_name,
+				       NULL);
+		g_free (scheme);
+		g_free (host_name);
 	}
 
 	if (address == NULL)
@@ -442,24 +499,28 @@ query_tooltip_cb (GtkWidget *proxy,
 	{
 		if (strstr (location, "%s") != NULL)
 		{
-			GnomeVFSURI *uri = gnome_vfs_uri_new (location);
-			if (uri != NULL)
+			char *scheme;
+			char *host_name;
+			
+			scheme = g_uri_parse_scheme (location);
+			host_name = ephy_string_get_host_name (location);
+		
+			if (title[0] == '\0')
 			{
-				if (title[0] == '\0')
-				{
-					text = g_markup_printf_escaped ("%s://%s",
-									gnome_vfs_uri_get_scheme (uri),
-									gnome_vfs_uri_get_host_name (uri));
-				}
-				else
-				{
-					text = g_markup_printf_escaped ("%s\n%s://%s",
-									title,
-									gnome_vfs_uri_get_scheme (uri),
-									gnome_vfs_uri_get_host_name (uri));
-				}
-				gnome_vfs_uri_unref (uri);
+				text = g_markup_printf_escaped ("%s://%s",
+								scheme,
+								host_name);
 			}
+			else
+			{
+				text = g_markup_printf_escaped ("%s\n%s://%s",
+								title,
+								scheme,
+								host_name);
+			}
+			
+			g_free (scheme);
+			g_free (host_name);
 		}
 		if (text == NULL)
 		{
@@ -487,7 +548,7 @@ connect_proxy (GtkAction *action,
 
 	LOG ("Connecting action %p to proxy %p", action, proxy);
 
-	GTK_ACTION_CLASS (parent_class)->connect_proxy (action, proxy);
+	GTK_ACTION_CLASS (ephy_bookmark_action_parent_class)->connect_proxy (action, proxy);
 
 	ephy_bookmark_action_sync_icon (action, NULL, proxy);
 	g_signal_connect_object (action, "notify::icon",
@@ -682,7 +743,7 @@ ephy_bookmark_action_dispose (GObject *object)
 		priv->cache_handler = 0;
 	}
 
-	parent_class->dispose (object);
+	G_OBJECT_CLASS (ephy_bookmark_action_parent_class)->dispose (object);
 }
 
 static void
@@ -691,8 +752,6 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 	GtkActionClass *action_class = GTK_ACTION_CLASS (class);
 
-	parent_class = g_type_class_peek_parent (class);
-
 	action_class->toolbar_item_type = GTK_TYPE_TOOL_ITEM;
 	action_class->create_tool_item = create_tool_item;
 	action_class->menu_item_type = GTK_TYPE_IMAGE_MENU_ITEM;
@@ -734,34 +793,6 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 	g_type_class_add_private (object_class, sizeof(EphyBookmarkActionPrivate));
 }
 
-GType
-ephy_bookmark_action_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo type_info =
-		{
-			sizeof (EphyBookmarkActionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) ephy_bookmark_action_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (EphyBookmarkAction),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_bookmark_action_init,
-		};
-
-		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
-					       "EphyBookmarkAction",
-					       &type_info, 0);
-	}
-
-	return type;
-}
-
 GtkAction *
 ephy_bookmark_action_new (EphyNode *node,
 			  const char *name)
