@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-link-action.c 7927 2008-02-10 18:26:22Z xan $
+ *  $Id$
  */
 
 #include "config.h"
@@ -27,10 +27,7 @@
 #include "ephy-debug.h"
 #include "ephy-gui.h"
 
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkmenutoolbutton.h>
+#include <gtk/gtk.h>
 
 G_DEFINE_TYPE_WITH_CODE (EphyLinkAction, ephy_link_action, GTK_TYPE_ACTION,
                          G_IMPLEMENT_INTERFACE (EPHY_TYPE_LINK,
