@@ -1,5 +1,5 @@
 /* 
- *  Copyright (C) 2005 Christian Persch
+ *  Copyright © 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: languages.h,v 1.6 2006/07/01 13:21:57 chpe Exp $
+ *  $Id$
  */
 
 static const char languages[][7] =
@@ -292,7 +292,6 @@ static const char languages[][7] =
 "he",
 "hsb",
 "hi",
-"hi-fj",
 "hi-in",
 "ho",
 "hr",
